@@ -10,12 +10,18 @@ function hzEntitiesToolbox($rootScope) {
         templateUrl: STATIC_URL + 'dashboard/project/entities/toolbox/entities-toolbox.html',
         restrict: 'E',
         scope: {
-            item: '='
+            item: '=',
+            searchText: '=',
+            autoRefresh: '='
         }
     };
     return directive;
 
     function link(scope, element, attrs) {
+
+        scope.autoRefresh = !!horizon.cookies.get('entitiesAutomaticRefresh');
+        console.log('Getting autoRefresh cookie: ', scope.autoRefresh);
+
         scope.broadcast = function(event) {
             console.log('click', event);
             $rootScope.$broadcast('toolbox-' + event);
